( cd usr/lib ; rm -rf libcanonufr2.so )
( cd usr/lib ; ln -sf libcanonufr2.so.1.0.0 libcanonufr2.so )
( cd usr/lib ; rm -rf libufr2filter.so )
( cd usr/lib ; ln -sf libufr2filter.so.1.0.0 libufr2filter.so )
( cd usr/lib ; rm -rf liblibcanonufr2.so.1 )
( cd usr/lib ; ln -sf libcanonufr2.so.1.0.0 liblibcanonufr2.so.1 )
( cd usr/lib ; rm -rf libufr2filter.so.1 )
( cd usr/lib ; ln -sf libufr2filter.so.1.0.0 libufr2filter.so.1 )
